<?php

	include_once("auxiliares/redimensionaImg.class.php");

	$redim = new Redimensiona();

	// require 'auxiliares/funcao-slug.php';

	// $caminhoAmigavel = slug($_POST['titulo']);

	// $selectSlug = mysql_query("SELECT * FROM adm_artigos WHERE slugArtigo = '".$caminhoAmigavel."' AND categoria = '".$_POST['categoria']."' AND id <> '".$_POST['idArtigo']."'");

	// $qtSlugs = mysql_num_rows($selectSlug);

	// if($qtSlugs > 0) $caminhoAmigavel .= "-".$qtSlugs;


	// Formata a data

	list($dia, $mes, $ano) = explode("/", $_POST['data']);

	$dataFormatada = $ano."-".$mes."-".$dia;

	if($_POST['chkManterCapa'] != 1){

		$selectCapaAtual = mysql_query("SELECT capa FROM adm_artigos WHERE id = '".mysql_escape_string($_POST['idArtigo'])."'");
		$capaAtual = mysql_result($selectCapaAtual, 0, 0);
		
		if(!empty($capaAtual)){
			unlink("imagens-site/galerias/thumbs/".$capaAtual);
			unlink("imagens-site/galerias/".$capaAtual);
		}

		if($_FILES['btnUpload']['size'] > 0){

			$numero = rand(1,99999999);
			$nome = $numero.$_FILES['btnUpload']['name'];
			$nome = $redim->tratar_arquivo_upload($nome);
			
			$tipoImagem = $_FILES['btnUpload']['type'];

			// Capa
		$fotoCapa = $_FILES['btnUpload']['tmp_name'];	
		$filenameCapa = $redim->GerarThumbs($fotoCapa, 48, 47, "imagens-site/galerias/capa", $tipoImagem, $nome);

			// Thumbs
			$fotoThumbs = $_FILES['btnUpload']['tmp_name'];	
			$filenameThumbs = $redim->GerarThumbs($fotoThumbs, 65, 65, "imagens-site/galerias/thumbs", $tipoImagem, $nome);

			// Medium
			$fotoMedium = $_FILES['btnUpload']['tmp_name'];	
			$filenameMedium = $redim->Redimensionar($fotoMedium, 183, 93, "imagens-site/galerias/medium", $tipoImagem, $nome);


			// Normal
			$foto = $_FILES['btnUpload']['tmp_name'];	
			$filenameDestaque = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/galerias", $tipoImagem, $nome);
		}

		if(!empty($filenameDestaque)){
			$updateQuery = "UPDATE adm_artigos SET titulo = '".mysql_escape_string(utf8_decode($_POST['titulo']))."', resumo = '".mysql_escape_string(utf8_decode($_POST['resumo']))."', data = '".mysql_escape_string($dataFormatada)."' , categoria = '".mysql_escape_string($_POST['categoria'])."' , texto = '".mysql_escape_string(utf8_decode($_POST['texto']))."', capa = '".mysql_escape_string($filenameDestaque)."', destaque = '".mysql_escape_string($_POST['chkProdutoDestaque'])."', subtitulo = '".mysql_escape_string(utf8_decode($_POST['subtitulo']))."', keywords = '".mysql_escape_string(utf8_decode(implode(",", $_POST['keywords'])))."' WHERE id = '".mysql_escape_string($_POST['idArtigo'])."'";
		}  

	} 

	if($_POST['chkManterCapa'] == 1 || empty($filenameDestaque)) {

		$updateQuery = "UPDATE adm_artigos SET titulo = '".mysql_escape_string(utf8_decode($_POST['titulo']))."', resumo = '".mysql_escape_string(utf8_decode($_POST['resumo']))."', data = '".mysql_escape_string($dataFormatada)."' , categoria = '".mysql_escape_string($_POST['categoria'])."' , texto = '".mysql_escape_string(utf8_decode($_POST['texto']))."', destaque = '".mysql_escape_string($_POST['chkProdutoDestaque'])."', subtitulo = '".mysql_escape_string(utf8_decode($_POST['subtitulo']))."', keywords = '".mysql_escape_string(utf8_decode(implode(",", $_POST['keywords'])))."' WHERE id = '".mysql_escape_string($_POST['idArtigo'])."'";
	}

	$updateMarca = mysql_query($updateQuery);

	$idArtigo = mysql_insert_id();

	if ($updateMarca) {

		$arrayImagens = array();

		for ($i=0; $i < count($_FILES['fotoGaleriaProduto']['name']); $i++) { 
			
			if ($_FILES['fotoGaleriaProduto']['size'][$i] > 0) {

				$numero = rand(1,99999999);
				$nome = $numero.$_FILES['fotoGaleriaProduto']['name'][$i];
				$nome = $redim->tratar_arquivo_upload($nome);
				
				$tipoImagem = $_FILES['fotoGaleriaProduto']['type'][$i];

				// Thumbs
				$fotoThumbs = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->GerarThumbs($fotoThumbs, 65, 65, "imagens-site/galerias/thumbs", $tipoImagem, $nome);

				// Medium
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->Redimensionar($foto, 230, 230, "imagens-site/galerias/medium", $tipoImagem, $nome);

				// Normal
				$foto = $_FILES['fotoGaleriaProduto']['tmp_name'][$i];	
				$filenameGallery = $redim->Redimensionar($foto, 1000, 1000, "imagens-site/galerias", $tipoImagem, $nome);

			}

			if(!empty($filenameGallery)){
				$arrayImagens[] = "('".mysql_escape_string($_POST['idArtigo'])."', '".mysql_escape_string($filenameGallery)."')";
			}

			
		}

		if(isset($arrayImagens)){
			$imagensGalleryDb = implode(",", $arrayImagens);

			$insertFotosGallery = mysql_query("INSERT INTO adm_gallery (id_artigo, arquivo) VALUES $imagensGalleryDb");
		}

		$fotos = isset($_POST['chkFotoGaleria']) ? $_POST['chkFotoGaleria'] : NULL;
		if(isset($fotos)){
			foreach ($fotos as $pos => $valor) {
				$selectFoto = mysql_query("SELECT arquivo FROM adm_gallery WHERE idGallery = '".mysql_escape_string($valor)."'");
				$fotoGaleria = mysql_result($selectFoto, 0, 0);
				unlink("imagens-site/galerias/thumbs/".$fotoGaleria);
				unlink("imagens-site/galerias/medium/".$fotoGaleria);
				unlink("imagens-site/galerias/".$fotoGaleria);
				$deleteFotoGaleria = mysql_query("DELETE FROM adm_gallery WHERE idGallery = '".mysql_escape_string($valor)."'");
			}
		}
	}


	if($updateMarca){
		?>
		<table>
			<tr>
				<td>
					Conte&uacute;do atualizado com Sucesso!
					<meta http-equiv="refresh" content="2; url=miolo.php?miolo=galerias&acao=alterar&id=1" />
				</td>
			</tr>
		</table>
		<?
	}

	if(!$updateMarca){
		?>
		<table>
			<tr>
				<td>
					Houve um erro ao atualizar o conte&uacute;do.
					<meta http-equiv="refresh" content="2; url=miolo.php?miolo=galerias&acao=alterar&id=1" />
				</td>
			</tr>
		</table>
		<?
	}

?>